@@ -45,7 +45,6 @@ class BaseImageLogger(BaseSampleLogger):
         If true, then logs will be writed on disk to "dir_path".
 
     """
-
     def __init__(
             self,
             phase: str = 'train',
@@ -73,23 +72,16 @@ class BaseImageLogger(BaseSampleLogger):
 
     def __init_transform(self, trainer):
         if self.phase == 'train':
-            transforms_ = trainer.train_dataloader.dataset.datasets.transform.transforms
-            if not isinstance(transforms_, list):
-                transforms_ = transforms_.transforms
             self.inv_transform = [inv_transform(
-                transforms_
-            )]
+                trainer.train_dataloader.dataset.datasets.transform.transforms)]
             return
         self.inv_transform = []
         for dataloader_idx in range(len(trainer.__getattribute__(f'{self.phase}_dataloaders'))):
-            transforms_ = trainer.__getattribute__(
-                f'{self.phase}_dataloaders'
-            )[dataloader_idx].dataset.transform.transforms
-            if not isinstance(transforms_, list):
-                transforms_ = transforms_.transforms
             self.inv_transform.append(
                 inv_transform(
-                    transforms_
+                    trainer.__getattribute__(
+                        f'{self.phase}_dataloaders'
+                    )[dataloader_idx].dataset.transform.transforms
                 )
             )
 
